""" Модуль содержит основной класс для работы с AR (Gravity One) """

from qdk.main import QDK


class ARQDK(QDK):
    """ Основной класс для взаимодействия с AR Gravity One """
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

    def get_status(self):
        """
        Извлечь статус AR.

        :return:
        """
        self.execute_method('get_status')

    def start_car_protocol(self, car_number, comm, course, car_choose_mode,
                           dlinnomer, polomka, orup_mode,
                           operator=None, carrier=None, trash_cat=None,
                           trash_type=None, old_car_num=None,
                           polygon_object=None):
        """
        Начать взвешивание для авто.

        :param car_number: Гос. номер авто.
        :param comm: Комментарий весовщика.
        :param course: Направление въезда.
        :param car_choose_mode: Спсособ вызова (auto/manual)
        :param dlinnomer: Протокол длинномер?
        :param polomka: Протокол поломка?
        :param orup_mode: Вид ОРУП (orup_short\orup_big)
        :param operator: id весовщика.
        :param carrier: Перевозчик.
        :param trash_cat: Категория груза.
        :param trash_type: Вид груза.
        :param old_car_num: Старый гос. номер.
        :param polygon_object: Название полигона
        :return:
        """
        info = {
            'car_number': car_number,
            'comm': comm,
            'course': course,
            'car_choose_mode': car_choose_mode,
            'dlinnomer': dlinnomer,
            'polomka': polomka,
            'orup_mode': orup_mode,
            'operator': operator,
            'carrier': carrier,
            'trash_cat': trash_cat,
            'trash_type': trash_type,
            'old_carnum': old_car_num,
            'polygon_object': polygon_object
        }
        self.execute_method('start_weight_round', info=info)

    def add_comment(self, record_id, comment):
        """
        Добавить комментарий к заезду.

        :param record_id: id записи.
        :param comment: Комментарий.
        :return:
        """
        self.execute_method('add_comment', record_id=record_id, comment=comment)

    def operate_gate_manual_control(self, operation, gate_name):
        """
        Работа со шлагбаумами.

        :param operation: Название операции (close|open):
        :param gate_name: Имя шлагбаума (entry/exit)
        :return:
        """
        self.execute_method('operate_gate_manual_control', operation=operation,
                            gate_name=gate_name)

    def change_opened_record(self, record_id, auto_id, car_number, carrier,
                             trash_cat_id, trash_type_id, comment,
                             polygon=None):
        """
        Изменить открытую запись.

        :param record_id: id зписи.
        :param auto_id: id авто.
        :param car_number: гос. номер авто.
        :param carrier: id перевозчика.
        :param trash_cat_id: id категории груза.
        :param trash_type_id: id вида груза.
        :param comment: комментарий весовщика.
        :param polygon: id полигона.
        :return:
        """
        self.execute_method('change_opened_record', record_id=record_id,
                            auto_id=auto_id, car_number=car_number,
                            carrier=carrier, trash_cat_id=trash_cat_id,
                            trash_type_id=trash_type_id, comment=comment,
                            polygon=polygon)

    def close_opened_record(self, record_id, time_out=None, alert='РЗ'):
        """
        Закрыть открытую запись.

        :param record_id: id записи.
        :param time_out: время выезда.
        :param alert: Алерт закрытия.
        :return:
        """
        self.execute_method('close_opened_record', record_id=record_id,
                            time_out=time_out, alert=alert)

    def get_unfinished_records(self):
        """
        Получить все незаконченные заезды (заезды без тары).

        :return:
        """
        self.execute_method('get_unfinished_records')

    def get_health_monitor(self):
        """
        Получить состояние монитора здоровья.

        :return:
        """
        self.execute_method('get_health_monitor')

    def try_auth_user(self,  username, password):
        """
        Попытка аутентификации юзера.

        :param username: Логин пользователя.
        :param password: Пароль пользователя.
        :return:
        """
        self.execute_method('try_auth_user', username=username,
                            password=password)

    def capture_cm_launched(self):
        """
        Зафиксировать запуск СМ.

        :return:
        """
        self.execute_method('capture_cm_launched')

    def capture_cm_terminated(self):
        """
        Зафиксировать завершение СМ.

        :return:
        """
        self.execute_method('capture_cm_terminated')

    def get_history(self, time_start, time_end, what_time='time_in',
                    trash_cat=None, trash_type=None, carrier=None,
                    auto_id=None, polygon_object_id=None, alerts=None):
        """
        Получить историю заездов.

        :return:
        """
        self.execute_method('get_history', time_start=time_start,
                            time_end=time_end, what_time=what_time,
                            trash_cat=trash_cat, trash_type=trash_type,
                            carrier=carrier, auto_id=auto_id,
                            polygon_object_id=polygon_object_id,
                            alerts=alerts)

    def get_table_info(self, table_name, only_active=True):
        """
        Получить содержимое таблицы.

        :param table_name: Имя таблицы.
        :param only_active: Только активные записи?
        :return:
        """
        self.execute_method('get_table_info', tablename=table_name)

    def get_last_event(self, auto_id):
        """
        Получить данные о последнем заезде авто.

        :param auto_id: ID авто.
        :return:
        """
        self.execute_method('get_last_event', auto_id=auto_id)

    def restart_unit(self):
        self.execute_method('restart_unit')
